Package: epibasix
Version: 1.5
Date: 2018-11-19
Title: Elementary Epidemiological Functions for Epidemiology and
        Biostatistics
Author: Michael A Rotondi <mrotondi@yorku.ca>
Maintainer: Michael A Rotondi <mrotondi@yorku.ca>
Depends: R (>= 2.01)
Description: Contains elementary tools for analysis of
        common epidemiological problems, ranging from sample size
        estimation, through 2x2 contingency table analysis and basic
        measures of agreement (kappa, sensitivity/specificity).
        Appropriate print and summary statements are also written to
        facilitate interpretation wherever possible.  Source code is 	commented throughout to facilitate modification.  The target audience includes advanced undergraduate and graduate students
        in epidemiology or biostatistics courses, and clinical researchers.
License: GPL (>= 2)
NeedsCompilation: no
Packaged: 2018-11-19 21:25:51 UTC; mrotondi
Repository: CRAN
Date/Publication: 2018-11-19 23:20:03 UTC
Built: R 4.6.0; ; 2026-04-25 18:39:15 UTC; unix
